/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ComponentRef } from '@angular/core';
import { Observable } from 'rxjs';
import { DialogComponent } from '../dialog.component';
import { DialogResult } from './dialog-result';
/**
 * Holds references to the object instance and published events of the Dialog.
 * Controls the Dialogs that were opened through the `DialogService`
 * ([see example]({% slug api_dialog_dialogservice %}#toc-open)).
 */
export declare class DialogRef {
    /**
     * Emits events when the Dialog is closed either through the **Close** button of the title bar or through the action buttons.
     * If the **Close** button of the title bar is clicked, `DialogResult` is a `DialogCloseResult` instance.
     * If the Dialog is closed through the action buttons, `DialogResult` contains the object that was passed when the Dialog was opened.
     * When `close` is called with an argument, the result is the passed argument.
     */
    result: Observable<DialogResult>;
    /**
     * A reference to the Dialog instance.
     */
    dialog: ComponentRef<DialogComponent>;
    /**
     * A reference to the child component of the Dialog.
     * Available when the Dialog is opened with [component content](slug:service_dialog#toc-rendering-the-content-area).
     */
    content: ComponentRef<any>;
    /**
     * Allows you to close the Dialog through code.
     * When called with no arguments,
     * the `result` Observable will be of type DialogCloseResult.
     * When called with an argument, the `result` Observable will hold the provided value.
     */
    close: Function;
}
